@@ -251,7 +251,7 @@
 #define INSTALL_SCRIPTDIR "/usr/local/mysql/bin"
 #define INSTALL_MYSQLDATADIR "/usr/local/mysql/data"
 #define INSTALL_MYSQLKEYRINGDIR "/usr/local/mysql/keyring"
-#define INSTALL_PLUGINTESTDIR "/build/percona-server/src/percona-server-5.7.11-4/plugin/query_response_time/tests;/build/percona-server/src/percona-server-5.7.11-4/plugin/scalability_metrics/tests;/build/percona-server/src/percona-server-5.7.11-4/plugin/audit_log/tests"
+#define INSTALL_PLUGINTESTDIR "/build/percona-server/src/percona-server-5.7.12-5/plugin/audit_log/tests;/build/percona-server/src/percona-server-5.7.12-5/plugin/scalability_metrics/tests;/build/percona-server/src/percona-server-5.7.12-5/plugin/query_response_time/tests"
 #define INSTALL_INFODIR "/usr/local/mysql/share/mysql/docs"
 #define INSTALL_MYSQLTESTDIR "/usr/local/mysql/mysql-test"
 #define INSTALL_DOCREADMEDIR "/usr/local/mysql/share/mysql"
@@ -364,6 +364,7 @@
 /* #undef HAVE_SYS_THREAD_SELFID */
 #define HAVE_SYS_GETTID 1
 /* #undef HAVE_PTHREAD_GETTHREADID_NP */
+/* #undef HAVE_PTHREAD_SETNAME_NP */
 #define HAVE_INTEGER_PTHREAD_SELF 1
 
 /* Platform-specific C++ compiler behaviors we rely upon */
@@ -385,15 +386,15 @@
 #define DOT_FRM_VERSION 6
 #define MYSQL_VERSION_MAJOR 5
 #define MYSQL_VERSION_MINOR 7
-#define MYSQL_VERSION_PATCH 11
-#define MYSQL_VERSION_EXTRA "-4"
+#define MYSQL_VERSION_PATCH 12
+#define MYSQL_VERSION_EXTRA "-5"
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 5.7.11-4"
+#define PACKAGE_STRING "MySQL Server 5.7.12-5"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "5.7.11-4"
-#define VERSION "5.7.11-4"
+#define PACKAGE_VERSION "5.7.12-5"
+#define VERSION "5.7.12-5"
 #define PROTOCOL_VERSION 10
 
 /*
@@ -419,7 +420,10 @@
 #define HAVE_FCNTL_H 1
 #define HAVE_GETADDRINFO 1
 #define HAVE_INTTYPES_H 1
+/* libevent's select.c is not Windows compatible */
+#ifndef _WIN32
 #define HAVE_SELECT 1
+#endif
 #define HAVE_SIGNAL_H 1
 #define HAVE_STDARG_H 1
 #define HAVE_STDINT_H 1
@@ -431,12 +435,18 @@
 #define HAVE_SYS_TYPES_H 1
 #define SIZEOF_CHAR 1
 
+/*
+ * Needed by libevent
+ */
+/* #undef HAVE_SOCKLEN_T */
+
 /* For --secure-file-priv */
 #define DEFAULT_SECURE_FILE_PRIV_DIR ""
 #define DEFAULT_SECURE_FILE_PRIV_EMBEDDED_DIR "NULL"
 /* #undef HAVE_LIBNUMA */
+#define WITH_NUMA 1
 
 /* For default value of --early_plugin_load */
-#define DEFAULT_EARLY_PLUGIN_LOAD "keyring_file=keyring_file.so"
+/* #undef DEFAULT_EARLY_PLUGIN_LOAD */
 
 #endif
